﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;

namespace Kompozyt
{
    public class Pracownik
    {
        private string imię, nazwisko, stanowisko;
        protected internal bool odwiedzony = false;

        public Pracownik(string imię, string nazwisko, string stanowisko) 
        {
            this.imię = imię;
            this.nazwisko = nazwisko;
            this.stanowisko = stanowisko;
        }

        public override string ToString()
        {
            return imię + " " + nazwisko + " (" + stanowisko + ")";
        }

        public virtual void WyświetlInformacje(int głębokość = 0)
        {
            zróbWcięcie(głębokość);
            Console.WriteLine(ToString());
            odwiedzony = true;
        }

        private void zróbWcięcie(int głębokość)
        {
            for (int i = 0; i < głębokość; i++)
                Console.Write("   ");
        }

        public virtual void Resetuj()
        {
            odwiedzony = false;
        }
    }

    public class Kierownik : Pracownik
    {
        private List<Pracownik> podwładni = new List<Pracownik>();

        public Kierownik(string imię, string nazwisko, string stanowisko)
            :base(imię, nazwisko, stanowisko)
        { }

        public void DodajPodwładnych(params Pracownik[] podwładni)
        {
            this.podwładni.AddRange(podwładni);
        }

        public override void WyświetlInformacje(int głębokość = 0)
        {
            base.WyświetlInformacje(głębokość);            
            Console.WriteLine("Podwładni:");            
            foreach (Pracownik podwładny in podwładni)
            {
                if(!podwładny.odwiedzony)
                    podwładny.WyświetlInformacje(głębokość + 1);
            }
        }

        public override void Resetuj()
        {
            base.Resetuj();
            foreach (Pracownik podwładny in podwładni)
            {
                if (podwładny.odwiedzony)
                    podwładny.Resetuj();
            }
        }
    }
}
